exceptiontools.UndefinedSpacingError
====================================

.. abjad-lineage:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError

.. autoclass:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UndefinedSpacingError.UndefinedSpacingError.__unicode__
   :noindex:
